@@ -12,7 +12,7 @@ from pkg_resources import iter_entry_points
 import sys
 
 
-__version__ = '0.3'
+__version__ = '0.3.2'
 
 
 def main():
@@ -27,6 +27,12 @@ def main():
         sys.stdout = writer(sys.stdout)
         sys.stderr = writer(sys.stderr)
 
+    # Python 2.6 won't work because of bug 13676
+    if sys.version_info < (2, 7):
+        sys.stderr.write("Warning: your version of Python, %s, is not "
+                         "supported\nThings WILL break if you don't upgrade "
+                         "to 2.7\n" % sys.version.split(' ', 1)[0])
+
     # Parses command-line
 
     # General options
