@@ -91,19 +91,28 @@ def create_directory(args):
                     unicode_(join_root(root,
                                        Path(run['workingdir']))))
             cmd += ' '.join('%s=%s' % (k, shell_escape(v))
-                            for k, v in run['environ'].items())
+                            for k, v in run['environ'].items()
+                            if k != 'PATH')
             cmd += ' '
+
+            # PATH
+            # Get the original PATH components
             path = [PosixPath(d)
                     for d in run['environ'].get('PATH', '').split(':')]
-            path = ':'.join(unicode_(join_root(root, d)) if d.root == '/'
-                            else unicode_(d)
-                            for d in path)
+            # The same paths but in the directory
+            dir_path = [join_root(root, d)
+                        for d in path
+                        if d.root == '/']
+            # Rebuild string
+            path = ':'.join(unicode_(d) for d in (dir_path + path))
             cmd += 'PATH=%s ' % shell_escape(path)
+
             # FIXME : Use exec -a or something if binary != argv[0]
             cmd += ' '.join(
                     shell_escape(a)
                     for a in [run['binary']] + run['argv'][1:])
             fp.write('%s\n' % cmd)
+    (target / 'script.sh').chmod(0o755)
 
     print("Experiment set up, run %s to start" % (target / 'script.sh'))
 
@@ -195,6 +204,7 @@ def create_chroot(args):
                      userspec,
                      shell_escape(unicode_(root)),
                      shell_escape(cmd)))
+    (target / 'script.sh').chmod(0o755)
 
     print("Experiment set up, run %s to start" % (target / 'script.sh'))
 
